==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkNetCDFPOPReader.java <==
// java wrapper for vtkNetCDFPOPReader object
//

package vtk;
import vtk.*;

public class vtkNetCDFPOPReader extends vtkRectilinearGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetStride_4(int id0,int id1,int id2);
  public void SetStride(int id0,int id1,int id2)
    { SetStride_4(id0,id1,id2); }

  private native void SetStride_5(int id0[]);
  public void SetStride(int id0[])
    { SetStride_5(id0); }

  private native int[]  GetStride_6();
  public int[]  GetStride()
    { return GetStride_6(); }

  private native int GetNumberOfVariableArrays_7();
  public int GetNumberOfVariableArrays()
    { return GetNumberOfVariableArrays_7(); }

  private native String GetVariableArrayName_8(int id0);
  public String GetVariableArrayName(int id0)
    { return GetVariableArrayName_8(id0); }

  private native int GetVariableArrayStatus_9(String id0);
  public int GetVariableArrayStatus(String id0)
    { return GetVariableArrayStatus_9(id0); }

  private native void SetVariableArrayStatus_10(String id0,int id1);
  public void SetVariableArrayStatus(String id0,int id1)
    { SetVariableArrayStatus_10(id0,id1); }

  public vtkNetCDFPOPReader() { super(); }

  public vtkNetCDFPOPReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkNetCDFPOPReader.java <==
// java wrapper for vtkNetCDFPOPReader object
//

package vtk;
import vtk.*;

public class vtkNetCDFPOPReader extends vtkRectilinearGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFileName_2(String id0);
  public void SetFileName(String id0)
    { SetFileName_2(id0); }

  private native String GetFileName_3();
  public String GetFileName()
    { return GetFileName_3(); }

  private native void SetStride_4(int id0,int id1,int id2);
  public void SetStride(int id0,int id1,int id2)
    { SetStride_4(id0,id1,id2); }

  private native void SetStride_5(int id0[]);
  public void SetStride(int id0[])
    { SetStride_5(id0); }

  private native int[]  GetStride_6();
  public int[]  GetStride()
    { return GetStride_6(); }

  private native int GetNumberOfVariableArrays_7();
  public int GetNumberOfVariableArrays()
    { return GetNumberOfVariableArrays_7(); }

  private native String GetVariableArrayName_8(int id0);
  public String GetVariableArrayName(int id0)
    { return GetVariableArrayName_8(id0); }

  private native int GetVariableArrayStatus_9(String id0);
  public int GetVariableArrayStatus(String id0)
    { return GetVariableArrayStatus_9(id0); }

  private native void SetVariableArrayStatus_10(String id0,int id1);
  public void SetVariableArrayStatus(String id0,int id1)
    { SetVariableArrayStatus_10(id0,id1); }

  public vtkNetCDFPOPReader() { super(); }

  public vtkNetCDFPOPReader(long id) { super(id); }
  public native long   VTKInit();

}
